@@ -38,7 +38,7 @@ from yapf.yapflib import py3compat
 from yapf.yapflib import style
 from yapf.yapflib import yapf_api
 
-__version__ = '0.15.2'
+__version__ = '0.16.2'
 
 
 def main(argv):
@@ -132,7 +132,7 @@ def main(argv):
     print('[style]')
     for option, docstring in sorted(style.Help().items()):
       for line in docstring.splitlines():
-        print('#', line)
+        print('#', line and ' ' or '', line, sep='')
       print(option.lower(), '=', style.Get(option), sep='')
       print()
     return 0
@@ -163,7 +163,7 @@ def main(argv):
       style_config = file_resources.GetDefaultStyleForDir(os.getcwd())
 
     source = [line.rstrip() for line in original_source]
-    reformatted_source, changed = yapf_api.FormatCode(
+    reformatted_source, _ = yapf_api.FormatCode(
         py3compat.unicode('\n'.join(source) + '\n'),
         filename='<stdin>',
         style_config=style_config,
