@@ -145,8 +145,8 @@ class UnwrappedLine(object):
   def __repr__(self):  # pragma: no cover
     tokens_repr = ','.join(
         ['{0}({1!r})'.format(tok.name, tok.value) for tok in self._tokens])
-    return 'UnwrappedLine(depth={0}, tokens=[{1}])'.format(self.depth,
-                                                           tokens_repr)
+    return 'UnwrappedLine(depth={0}, tokens=[{1}])'.format(
+        self.depth, tokens_repr)
 
   ############################################################################
   # Properties                                                               #
@@ -226,6 +226,9 @@ def _SpaceRequiredBetween(left, right):
   if lval == '.' and rval == 'import':
     # Space after the '.' in an import statement.
     return True
+  if lval == '=' and rval == '.':
+    # Space between equal and '.' as in "X = ...".
+    return True
   if ((right.is_keyword or right.is_name) and
       (left.is_keyword or left.is_name)):
     # Don't merge two keywords/identifiers.
@@ -397,19 +400,19 @@ def IsSurroundedByBrackets(tok):
 
     if previous_token.value == '(':
       if paren_count == 0:
-        return True
+        return previous_token
       paren_count += 1
     elif previous_token.value == '{':
       if brace_count == 0:
-        return True
+        return previous_token
       brace_count += 1
     elif previous_token.value == '[':
       if sq_bracket_count == 0:
-        return True
+        return previous_token
       sq_bracket_count += 1
 
     previous_token = previous_token.previous_token
-  return False
+  return None
 
 
 _LOGICAL_OPERATORS = frozenset({'and', 'or'})
