@@ -215,6 +215,18 @@ class BasicReformatterTest(yapf_test_helper.YAPFTest):
     uwlines = yapf_test_helper.ParseAndUnwrap(code)
     self.assertCodeEqual(code, reformatter.Reformat(uwlines))
 
+  def testCommentsWithTrailingSpaces(self):
+    unformatted_code = textwrap.dedent("""\
+        # Thing 1    
+        # Thing 2    
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        # Thing 1
+        # Thing 2
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertCodeEqual(expected_formatted_code, reformatter.Reformat(uwlines))
+
   def testCommentsInDataLiteral(self):
     code = textwrap.dedent("""\
         def f():
@@ -1163,6 +1175,24 @@ xxxxxxxxxxx, yyyyyyyyyyyy, vvvvvvvvv)
     uwlines = yapf_test_helper.ParseAndUnwrap(code)
     self.assertCodeEqual(code, reformatter.Reformat(uwlines))
 
+    unformatted_code = textwrap.dedent("""\
+        def _():
+          if True:
+            if True:
+              if contract == allow_contract and attr_dict.get(if_attribute) == has_value:
+                return True
+        """)
+    expected_code = textwrap.dedent("""\
+        def _():
+          if True:
+            if True:
+              if contract == allow_contract and attr_dict.get(
+                  if_attribute) == has_value:
+                return True
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertEqual(expected_code, reformatter.Reformat(uwlines))
+
   def testDictSetGenerator(self):
     code = textwrap.dedent("""\
         foo = {
@@ -1465,6 +1495,17 @@ xxxxxxxxxxx, yyyyyyyyyyyy, vvvvvvvvv)
     uwlines = yapf_test_helper.ParseAndUnwrap(code)
     self.assertCodeEqual(code, reformatter.Reformat(uwlines))
 
+    code = textwrap.dedent("""\
+      def foo():
+        return [
+            Bar(xxx='some string',
+                yyy='another long string',
+                zzz='a third long string')
+        ]
+      """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(code)
+    self.assertCodeEqual(code, reformatter.Reformat(uwlines))
+
   def testCommentColumnLimitOverflow(self):
     code = textwrap.dedent("""\
       def f():
@@ -2084,6 +2125,162 @@ xxxxxxxxxxx, yyyyyyyyyyyy, vvvvvvvvv)
     finally:
       style.SetGlobalStyle(style.CreateChromiumStyle())
 
+  def testTupleCohesion(self):
+    unformatted_code = textwrap.dedent("""\
+        def f():
+          this_is_a_very_long_function_name(an_extremely_long_variable_name, (
+              'a string that may be too long %s' % 'M15'))
+        """)
+    expected_code = textwrap.dedent("""\
+        def f():
+          this_is_a_very_long_function_name(
+              an_extremely_long_variable_name,
+              ('a string that may be too long %s' % 'M15'))
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertEqual(expected_code, reformatter.Reformat(uwlines))
+
+  def testSubscriptExpression(self):
+    code = textwrap.dedent("""\
+        foo = d[not a]
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(code)
+    self.assertCodeEqual(code, reformatter.Reformat(uwlines))
+
+  def testListWithFunctionCalls(self):
+    unformatted_code = textwrap.dedent("""\
+        def foo():
+          return [
+              Bar(
+                  xxx='some string',
+                  yyy='another long string',
+                  zzz='a third long string'), Bar(
+                      xxx='some string',
+                      yyy='another long string',
+                      zzz='a third long string')
+          ]
+        """)
+    expected_code = textwrap.dedent("""\
+        def foo():
+          return [
+              Bar(xxx='some string',
+                  yyy='another long string',
+                  zzz='a third long string'),
+              Bar(xxx='some string',
+                  yyy='another long string',
+                  zzz='a third long string')
+          ]
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertEqual(expected_code, reformatter.Reformat(uwlines))
+
+  def testEllipses(self):
+    unformatted_code = textwrap.dedent("""\
+        X=...
+        """)
+    expected_code = textwrap.dedent("""\
+        X = ...
+        """)
+    uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+    self.assertEqual(expected_code, reformatter.Reformat(uwlines))
+
+  def testSplittingBeforeFirstArgumentOnFunctionCall(self):
+    """Tests split_before_first_argument on a function call."""
+    try:
+      style.SetGlobalStyle(
+          style.CreateStyleFromConfig(
+              '{based_on_style: chromium, split_before_first_argument: True}'))
+      unformatted_code = textwrap.dedent("""\
+          a_very_long_function_name("long string with formatting {0:s}".format(
+              "mystring"))
+          """)
+      expected_formatted_code = textwrap.dedent("""\
+          a_very_long_function_name(
+              "long string with formatting {0:s}".format("mystring"))
+          """)
+      uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+      self.assertCodeEqual(expected_formatted_code,
+                           reformatter.Reformat(uwlines))
+    finally:
+      style.SetGlobalStyle(style.CreateChromiumStyle())
+
+  def testSplittingBeforeFirstArgumentOnFunctionDefinition(self):
+    """Tests split_before_first_argument on a function definition."""
+    try:
+      style.SetGlobalStyle(
+          style.CreateStyleFromConfig(
+              '{based_on_style: chromium, split_before_first_argument: True}'))
+      unformatted_code = textwrap.dedent("""\
+          def _GetNumberOfSecondsFromElements(year, month, day, hours,
+                                              minutes, seconds, microseconds):
+            return
+          """)
+      expected_formatted_code = textwrap.dedent("""\
+          def _GetNumberOfSecondsFromElements(
+              year, month, day, hours, minutes, seconds, microseconds):
+            return
+          """)
+      uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+      self.assertCodeEqual(expected_formatted_code,
+                           reformatter.Reformat(uwlines))
+    finally:
+      style.SetGlobalStyle(style.CreateChromiumStyle())
+
+  def testSplittingBeforeFirstArgumentOnCompoundStatement(self):
+    """Tests split_before_first_argument on a compound statement."""
+    try:
+      style.SetGlobalStyle(
+          style.CreateStyleFromConfig(
+              '{based_on_style: chromium, split_before_first_argument: True}'))
+      unformatted_code = textwrap.dedent("""\
+          if (long_argument_name_1 == 1 or
+              long_argument_name_2 == 2 or
+              long_argument_name_3 == 3 or
+              long_argument_name_4 == 4):
+            pass
+          """)
+      expected_formatted_code = textwrap.dedent("""\
+          if (long_argument_name_1 == 1 or long_argument_name_2 == 2 or
+              long_argument_name_3 == 3 or long_argument_name_4 == 4):
+            pass
+          """)
+      uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+      self.assertCodeEqual(expected_formatted_code,
+                           reformatter.Reformat(uwlines))
+    finally:
+      style.SetGlobalStyle(style.CreateChromiumStyle())
+
+  def testCoalesceBracketsOnDict(self):
+    """Tests coalesce_brackets on a dictionary."""
+    try:
+      style.SetGlobalStyle(
+          style.CreateStyleFromConfig(
+              '{based_on_style: chromium, coalesce_brackets: True}'))
+      unformatted_code = textwrap.dedent("""\
+          date_time_values = {
+              u'year': year,
+              u'month': month,
+              u'day_of_month': day_of_month,
+              u'hours': hours,
+              u'minutes': minutes,
+              u'seconds': seconds
+          }
+          """)
+      expected_formatted_code = textwrap.dedent("""\
+          date_time_values = {
+              u'year': year,
+              u'month': month,
+              u'day_of_month': day_of_month,
+              u'hours': hours,
+              u'minutes': minutes,
+              u'seconds': seconds}
+          """)
+      uwlines = yapf_test_helper.ParseAndUnwrap(unformatted_code)
+      self.assertCodeEqual(expected_formatted_code,
+                           reformatter.Reformat(uwlines))
+    finally:
+      style.SetGlobalStyle(style.CreateChromiumStyle())
+
 
 if __name__ == '__main__':
   unittest.main()
