@@ -1017,8 +1017,7 @@ class CommandLineTest(unittest.TestCase):
     expected_formatted_code = textwrap.dedent("""\
        some_long_function_name_foo({
            'first_argument_of_the_thing': id,
-           'second_argument_of_the_thing': "some thing"
-       })
+           'second_argument_of_the_thing': "some thing"})
        """)
     with utils.NamedTempFile(dirname=self.test_tmpdir, mode='w') as (f, name):
       f.write(
@@ -1137,8 +1136,8 @@ class CommandLineTest(unittest.TestCase):
             pass
         """)
 
-    with utils.NamedTempFile(
-        dirname=self.test_tmpdir) as (stylefile, stylepath):
+    with utils.NamedTempFile(dirname=self.test_tmpdir) as (stylefile,
+                                                           stylepath):
       p = subprocess.Popen(
           YAPF_BINARY + ['--style-help'],
           stdout=stylefile,
